﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Configuration;
using System.Web;
using System.Web.Mvc;
using Kendo.Mvc;
using Kendo.Mvc.UI;
using Kendo.Mvc.Extensions;
using Business;
using Models;

namespace MVC_Controls_Kendo.Controllers
{
    public class HomeController : Controller
    {
        BusinessLayer _business;
        string yearId = "2013/2014";
        string sportId = Constant.SportId.All;

        public HomeController()
        {
            _business = new BusinessLayer(ConfigurationManager.ConnectionStrings["OTPTESTEntities"].ConnectionString);
        }

        #region Sport Page Info

        public ActionResult SportPage()
        {
            this._business.PopulateMaintenanceSportsViewData(ViewData, sportId);

            return View();
        }

        public ActionResult MaintenanceSportsAjax(DataSourceRequest request)
        {
            //retreive sports
            var model = this._business.GetMaintenanceSportsGridSportViewModel(yearId, "S_O_AC_C");

            DataSourceResult sports = model.ToDataSourceResult(request);

            return Json(sports, JsonRequestBehavior.AllowGet);
        }

        [AcceptVerbs(HttpVerbs.Post)]
        public ActionResult UpdateMaintenanceSports(DataSourceRequest request, string sportId)
        {
            var updatedModel = new MaintenanceSportsGridSportViewModel();

            return MaintenanceSportsAjax(request);
        }

        public ActionResult MaintenanceDisciplinesAjax(DataSourceRequest request, string sportId)
        {
            var model = this._business.GetMaintenanceSportsGridDisciplineViewModel(sportId);

            DataSourceResult disciplines = model.ToDataSourceResult(request);

            return Json(disciplines, JsonRequestBehavior.AllowGet);
        }

        [AcceptVerbs(HttpVerbs.Post)]
        public ActionResult InsertMaintenanceDisciplines(DataSourceRequest request, string parentSportId)
        {
            var updatedModel = new MaintenanceSportsGridDisciplineViewModel();

            return MaintenanceDisciplinesAjax(request, parentSportId);
        }

        [AcceptVerbs(HttpVerbs.Post)]
        public ActionResult UpdateMaintenanceDisciplines(DataSourceRequest request, string id)
        {
            var updatedModel = new MaintenanceSportsGridDisciplineViewModel();
            updatedModel.DisciplineId = id;

            return MaintenanceDisciplinesAjax(request, id);
        }

        [AcceptVerbs(HttpVerbs.Post)]
        public ActionResult DeleteMaintenanceDisciplines(DataSourceRequest request, string id)
        {
            return MaintenanceDisciplinesAjax(request, id);
        }

        public ActionResult MaintenanceEventsAjax(DataSourceRequest request, string disciplineId)
        {
            var model = this._business.GetMaintenanceSportsGridEventViewModel(disciplineId);

            DataSourceResult events = model.ToDataSourceResult(request);

            return Json(events, JsonRequestBehavior.AllowGet);
        }

        [AcceptVerbs(HttpVerbs.Post)]
        public ActionResult InsertMaintenanceEvents(DataSourceRequest request, string parentDisciplineId)
        {
            var updatedModel = new MaintenanceSportsGridEventViewModel();

            return MaintenanceEventsAjax(request, parentDisciplineId);
        }

        [AcceptVerbs(HttpVerbs.Post)]
        public ActionResult UpdateMaintenanceEvents(DataSourceRequest request, string id)
        {
            var updatedModel = new MaintenanceSportsGridEventViewModel();
            updatedModel.EventId = id;

            return MaintenanceEventsAjax(request, id);
        }

        [AcceptVerbs(HttpVerbs.Post)]
        public ActionResult DeleteMaintenanceEvents(DataSourceRequest request, string id)
        {
            return MaintenanceEventsAjax(request, id);
        }

        #endregion Sport Page Info

        //#region Athletes

        //public ActionResult Athletes()
        //{
        //    this._business.PopulateMaintenanceResourcesViewData(ViewData, "0", sportId, yearId);            
            
        //    return View();
        //}

        //[AcceptVerbs(HttpVerbs.Post)]
        //public ActionResult InsertAthlete(DataSourceRequest request)
        //{
        //    var updatedModel = new MaintenanceAthletesAthleteGridViewModel();

        //    return AthletesMaintenanceAthleteGridAjax(request);
        //}

        //[AcceptVerbs(HttpVerbs.Post)]
        //public ActionResult UpdateAthlete(DataSourceRequest request, string id)
        //{
        //    var updatedModel = new MaintenanceAthletesAthleteGridViewModel();
        //    updatedModel.ResourceId = int.Parse(id);

        //    return AthletesMaintenanceAthleteGridAjax(request);
        //}

        //[AcceptVerbs(HttpVerbs.Post)]
        //public ActionResult DeleteAthlete(DataSourceRequest request, string id)
        //{
        //    return AthletesMaintenanceAthleteGridAjax(request);
        //}

        //public ActionResult AthletesMaintenanceAthleteGridAjax([DataSourceRequest]DataSourceRequest request)
        //{
        //    int total = 0;

        //    var model = this._business.GetMaintenanceAthletesAthleteGridViewModel(sportId, yearId, request, out total);

        //    DataSourceResult result = new DataSourceResult
        //    {
        //        Data = model.AsQueryable(),
        //        Total = total
        //    };

        //    return Json(result);
        //}

        //#endregion Athletes

        //#region Athletes General Tab

        //[AcceptVerbs(HttpVerbs.Post)]
        //public ActionResult AthletesGeneralInfo(string id)
        //{
        //    this._business.PopulateMaintenanceResourcesViewData(ViewData, id, sportId, yearId);

        //    MaintenanceAthletesGeneralInfoViewModel model = null;

        //    if (!string.IsNullOrEmpty(id))
        //    {
        //        model = this._business.GetMaintenanceAthletesGeneralInfoViewModel(int.Parse(id));
        //    }

        //    return PartialView(model);
        //}

        //[AcceptVerbs(HttpVerbs.Post)]
        //public ActionResult AthletesGeneralInfoSave(string id, FormCollection collection)
        //{
        //    return View("Athletes");
        //}

        //#endregion Athletes General Tab

        //#region Athletes SportInfo Tab

        //public ActionResult AthletesSportsInfo(string id)
        //{
        //    this._business.PopulateMaintenanceResourcesViewData(ViewData, id, sportId, yearId);

        //    return PartialView();
        //}

        //public ActionResult AthletesSportsInfoAjax([DataSourceRequest]DataSourceRequest request, string resourceId)
        //{
        //    List<MaintenanceAthletesSportsInfoViewModel> model = null;

        //    model = this._business.GetMaintenanceAthletesSportsInfoViewModel(Convert.ToInt32(resourceId), (string)ViewData["CurrentYearID"]);

        //    if (model == null)
        //        return null;

        //    DataSourceResult result = model.ToDataSourceResult(request);

        //    return Json(result, JsonRequestBehavior.AllowGet);
        //}

        //[AcceptVerbs(HttpVerbs.Post)]
        //public ActionResult InsertAthletesSport(DataSourceRequest request, string resourceId)
        //{
        //    var updatedModel = new MaintenanceAthletesSportsInfoViewModel();

        //    if (TryUpdateModel(updatedModel))
        //    {
        //        updatedModel.ResourceId = int.Parse(resourceId);
        //    }

        //    return AthletesSportsInfoAjax(request, resourceId);
        //}

        //[AcceptVerbs(HttpVerbs.Post)]
        //public ActionResult UpdateAthletesSport(DataSourceRequest request, string resourceSportId)
        //{
        //    var updatedModel = new MaintenanceAthletesSportsInfoViewModel();

        //    return AthletesSportsInfoAjax(request, (string)ViewData["resourceId"]);
        //}

        //[AcceptVerbs(HttpVerbs.Post)]
        //public ActionResult DeleteAthletesSport(DataSourceRequest request, int resourceSportId)
        //{
        //    return AthletesSportsInfoAjax(request, (string)ViewData["resourceId"]);
        //}

        //public ActionResult AthletesBenchmarkSportsAjax(DataSourceRequest request, string resourceSportId)
        //{
        //    List<MaintenanceAthletesBenchmarkSportsViewModel> model = null;

        //    if (!string.IsNullOrEmpty(resourceSportId))
        //    {
        //        model = this._business.GetMaintenanceAthletesBenchmarkSportsViewModel("2013/2014", resourceSportId);

        //        if (model == null)
        //            return null;

        //        DataSourceResult result = model.ToDataSourceResult(request);

        //        return Json(result, JsonRequestBehavior.AllowGet);
        //    }

        //    return null;
        //}

        //[AcceptVerbs(HttpVerbs.Post)]
        //public ActionResult InsertAthletesBenchmark(DataSourceRequest request, string resourceSportId)
        //{
        //    var updatedModel = new MaintenanceAthletesBenchmarkSportsViewModel();
        //    updatedModel.ResourceSportId = int.Parse(resourceSportId);
        //    updatedModel.YearId = (string)ViewBag.YearId;

        //    return AthletesBenchmarkSportsAjax(request, resourceSportId);
        //}

        //[AcceptVerbs(HttpVerbs.Post)]
        //public ActionResult UpdateAthletesBenchmark(DataSourceRequest request, string resourceSportId)
        //{
        //    var updatedModel = new MaintenanceAthletesBenchmarkSportsViewModel();

        //    updatedModel.ResourceSportId = int.Parse(resourceSportId);

        //    return AthletesBenchmarkSportsAjax(request, resourceSportId);
        //}

        //[AcceptVerbs(HttpVerbs.Post)]
        //public ActionResult DeleteAthletesBenchmark(DataSourceRequest request, string resourceSportId)
        //{
        //    //var benchmarkResourceId = int.Parse(benchmarkResourceId);
        //    //int changes = this._resourceBL.DeleteBenchmarkResource(int.Parse(benchmarkResourceId));

        //    return AthletesBenchmarkSportsAjax(request, resourceSportId);
        //}

        //#endregion Athletes SportInfo Tab

        public ActionResult Index()
        {
            ViewBag.Message = "OTP Test Web Pages";

            return View();
        }

        public ActionResult About()
        {
            ViewBag.Message = "Your app description page.";

            return View();
        }

        public ActionResult Contact()
        {
            ViewBag.Message = "Your contact page.";

            return View();
        }
    }
}
